@@ -665,6 +665,13 @@ void TabbedViewContainer::openTabContextMenu(int index, const QPoint& pos)
 {
     _contextMenuTabIndex = index;
 
+    // Enable 'Detach Tab' menu item only if there is more than 1 tab
+    QList<QAction *> menuActions = _contextPopupMenu->actions();
+    if (_tabBar->count() == 1)
+        menuActions.first()->setEnabled(false);
+    else
+        menuActions.first()->setEnabled(true);
+
     _contextPopupMenu->exec(pos);
 }
 
